pub enum MutinyProxyCommand {
Disconnect {
to: Vec<u8>,
from: Vec<u8>,
},
Ping,
}Expand description
MutinyProxyCommand are proxy commands that get sent to/from the clients to/from the proxy.
Disconnect:
The proxy uses this to inform a client that one of the peers
that they were connected to has gone away.
The clients should use this to inform the proxy that they are
asking to be disconnected to one of the peers that they are
currently connected to. The proxy will send the other peer
the Disconnect message afterwards.
Ping: A message for the clients to send to us to keep websocket alive.
Variants